@@ -1,10 +1,11 @@
 import os
 import pkg_resources
+from .Toolchain import get_native_toolchain
 
 PACKAGE_DATA_PATH = pkg_resources.resource_filename('cfiddle', 'resources/')
 
 def cfiddle_lib_path():
-    return os.path.join(PACKAGE_DATA_PATH, "libcfiddle", "build")
+    return os.path.join(PACKAGE_DATA_PATH, "libcfiddle", "build", get_native_toolchain())
 
 def cfiddle_include_path():
     return os.path.join(PACKAGE_DATA_PATH, "include")
