@@ -1,4 +1,5 @@
 import ctypes
+from ..Exceptions import CFiddleException
 
 def install_perf_counters(perf_counters):
     libcfiddle = _load_libcfiddle()
@@ -7,7 +8,7 @@ def install_perf_counters(perf_counters):
         if isinstance(pc, str):
             libcfiddle.add_perf_counter(ctypes.c_char_p(pc.encode()))
         else:
-            raise ValueError("Expected instance of 'str' not {type(pc).__name__}.")
+            raise UnknownPerformanceCounter("Expected instance of 'str' not {type(pc).__name__}.")
 
 def are_perf_counters_available():
     return bool(_load_libcfiddle().are_perf_counters_available())
@@ -20,3 +21,6 @@ def clear_perf_counters():
 def _load_libcfiddle():
     return  ctypes.CDLL("libcfiddle.so")
 
+
+class UnknownPerformanceCounter(CFiddleException):
+    pass
